# Generated by Django 3.2.21 on 2023-10-03 15:29

# Django
import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("django_easy_quiz", "0002_auto_20230929_1725"),
    ]

    operations = [
        migrations.AlterModelOptions(
            name="moreinfoanswer",
            options={
                "verbose_name": "Réponse de quiz 'plus d'info'",
                "verbose_name_plural": "Réponses de quiz 'plus d'info'",
            },
        ),
        migrations.AlterModelOptions(
            name="moreinfoquestion",
            options={
                "verbose_name": "Question de quiz 'plus d'infos'",
                "verbose_name_plural": "Questions de quiz 'plus d'infos'",
            },
        ),
        migrations.AlterModelOptions(
            name="moreinfoquiz",
            options={
                "verbose_name": "Quiz plus d'infos",
                "verbose_name_plural": "Quizs plus d'infos",
            },
        ),
        migrations.AlterModelOptions(
            name="savedquiz",
            options={
                "verbose_name": "Quiz Sauvegardé",
                "verbose_name_plural": "Quiz Sauvegardés",
            },
        ),
        migrations.AddField(
            model_name="moreinfoquestion",
            name="answer_is_list",
            field=models.BooleanField(
                default=False,
                help_text="Check this parameter to display a big list of answers using a select input and not radio buttons.",
            ),
        ),
        migrations.AlterField(
            model_name="interpretationplugin",
            name="title_level",
            field=models.CharField(
                choices=[
                    ("h1", "Titre niveau 1 (<h1>)"),
                    ("h2", "Titre niveau 2 (<h2>)"),
                    ("h3", "Titre niveau 3 (<h3>)"),
                    ("h4", "Titre niveau 4 (<h4>)"),
                    ("h5", "Titre niveau 5 (<h5>)"),
                    ("h6", "Titre niveau 6 (<h6>)"),
                ],
                help_text="Title level",
                max_length=4,
            ),
        ),
        migrations.AlterField(
            model_name="interpretationquiz",
            name="more_info_quiz",
            field=models.ForeignKey(
                blank=True,
                default=None,
                help_text="Choisir un quiz 'plus d'infos' va l'afficher à la fin du quiz principal.",
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                to="django_easy_quiz.moreinfoquiz",
            ),
        ),
        migrations.AlterField(
            model_name="moreinfoquestion",
            name="answer_is_txt",
            field=models.BooleanField(
                default=False,
                help_text="Cochez cette case pour autoriser les réponses 'texte libre' au lieu des réponses prédéfinies.",
            ),
        ),
        migrations.AlterField(
            model_name="moreinfoquiz",
            name="name",
            field=models.CharField(
                help_text="Sera affiché sous les résultats.", max_length=255
            ),
        ),
        migrations.AlterField(
            model_name="weightedanswersplugin",
            name="title_level",
            field=models.CharField(
                choices=[
                    ("h1", "Titre niveau 1 (<h1>)"),
                    ("h2", "Titre niveau 2 (<h2>)"),
                    ("h3", "Titre niveau 3 (<h3>)"),
                    ("h4", "Titre niveau 4 (<h4>)"),
                    ("h5", "Titre niveau 5 (<h5>)"),
                    ("h6", "Titre niveau 6 (<h6>)"),
                ],
                help_text="Title level",
                max_length=4,
            ),
        ),
        migrations.AlterField(
            model_name="weightedanswersquiz",
            name="more_info_quiz",
            field=models.ForeignKey(
                blank=True,
                default=None,
                help_text="Choisir un quiz 'plus d'infos' va l'afficher à la fin du quiz principal.",
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                to="django_easy_quiz.moreinfoquiz",
            ),
        ),
    ]
