# Generated by Django 3.2.21 on 2023-10-09 15:07

# Django
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("django_easy_quiz", "0003_auto_20231003_1729"),
    ]

    operations = [
        migrations.AlterField(
            model_name="savedquiz",
            name="answers",
            field=models.JSONField(default=dict),
        ),
        migrations.AlterField(
            model_name="savedquiz",
            name="conclusion",
            field=models.JSONField(default=dict),
        ),
        migrations.AlterField(
            model_name="savedquiz",
            name="more_infos",
            field=models.JSONField(default=dict),
        ),
    ]
